@@ -12,7 +12,7 @@ from datetime import datetime
 
 from tcsoa.config import TcSoaConfig
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBoClass
+from tcsoa.base import TcBoClass
 
 
 class RestBackend:
