@@ -1,10 +1,10 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import Ac0Comment, BusinessObject, Ac0Conversation, User
+from tcsoa.gen.BusinessObjects import BusinessObject, User, Ac0Comment, Ac0Conversation
 from tcsoa.gen.ActiveCollaboration._2020_12.ActiveCollaboration import CreateOrUpdateCommentRequest, CreateOrUpdateConversationRequest, ReadResponse
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ActiveCollaborationService(TcService):
