@@ -1,5 +1,5 @@
 from tcsoa.gen.ActiveCollaboration._2020_12.services import ActiveCollaborationService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ActiveCollaborationService(TcService):
