@@ -1,6 +1,6 @@
 from tcsoa.gen.ClassificationCommon._2020_01.services import ClassificationService as imp0
 from tcsoa.gen.ClassificationCommon._2020_12.services import ClassificationService as imp1
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ClassificationService(TcService):
