@@ -1,8 +1,8 @@
 from __future__ import annotations
 
-from tcsoa.gen.Diagramming._2011_06.DiagramManagement import CreateDiagramInputInfo, GetDiagramMembersResponse, CreateOrUpdateTemplateResponse, OpenDiagramInputInfo, SaveDiagramResponse, SaveDiagramInputInfo, GetDiagramMembersInputInfo, CreateDiagramResponse, OpenDiagramResponse, CreateOrUpdateTemplateInputInfo
+from tcsoa.gen.Diagramming._2011_06.DiagramManagement import CreateDiagramInputInfo, GetDiagramMembersResponse, OpenDiagramInputInfo, SaveDiagramInputInfo, OpenDiagramResponse, SaveDiagramResponse, GetDiagramMembersInputInfo, CreateOrUpdateTemplateInputInfo, CreateDiagramResponse, CreateOrUpdateTemplateResponse
 from typing import List
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class DiagramManagementService(TcService):
