@@ -1,5 +1,5 @@
 from tcsoa.gen.DocMgmtAw._2017_06.services import DocMgmtService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class DocMgmtService(TcService):
