@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import PIEActionRule, BusinessObject, Group, PropertySet, Filter, POM_imc, TransferOptionSet, Role, TransferMode, ClosureRule, ImanFile, User
+from tcsoa.gen.BusinessObjects import BusinessObject, Group, ClosureRule, ImanFile, PropertySet, Filter, TransferOptionSet, POM_imc, TransferMode, User, Role, PIEActionRule
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
