@@ -3,7 +3,7 @@ from tcsoa.gen.ImportExport._2007_06.services import FileImportExportService as
 from tcsoa.gen.ImportExport._2008_06.services import FileImportExportService as imp2
 from tcsoa.gen.ImportExport._2017_11.services import FileImportExportService as imp3
 from tcsoa.gen.ImportExport._2012_09.services import FileImportExportService as imp4
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class FileImportExportService(TcService):
