@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import Fnd0BOMLineLite, PSBOMViewRevision, BOMWindow, Dataset, ImanFile
+from tcsoa.gen.BusinessObjects import ImanFile, PSBOMViewRevision, Fnd0BOMLineLite, Dataset, BOMWindow
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
