@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from tcsoa.gen.BusinessObjects import Awb0Element
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
