@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from tcsoa.gen.Internal.MultiSite._2007_06.RemoteOperation import IdsmIeOpt, IdsmObjectDesc, DateElement, IdsmIeFailures, SendObjectsSubstitutions, SendObjectsRetentions
+from tcsoa.gen.Internal.MultiSite._2007_06.RemoteOperation import IdsmIeOpt, SendObjectsRetentions, IdsmObjectDesc, DateElement, SendObjectsSubstitutions, IdsmIeFailures
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
