@@ -1,8 +1,8 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import TransferOptionSet, BusinessObject, POM_imc
+from tcsoa.gen.BusinessObjects import BusinessObject, POM_imc, TransferOptionSet
 from typing import List
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
