@@ -1,7 +1,7 @@
 from tcsoa.gen.Internal_Ai._2008_06.services import AiService as imp0
 from tcsoa.gen.Internal_Ai._2016_03.services import AiService as imp1
 from tcsoa.gen.Internal_Ai._2016_04.services import AiService as imp2
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class AiService(TcService):
