@@ -1,5 +1,5 @@
 from tcsoa.gen.Internal_AuditManager._2012_09.services import ProcessHistoryManagementService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ProcessHistoryManagementService(TcService):
