@@ -1,5 +1,5 @@
 from tcsoa.gen.Internal_EntCba._2019_12.services import AlignmentsService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class AlignmentsService(TcService):
