@@ -1,8 +1,8 @@
 from __future__ import annotations
 
 from typing import List
-from tcsoa.gen.Internal.Requirementsmanagement._2012_10.RequirementsManagement import MatchLineInputData, TraceabilityMatrixInfo1, MatchedLineResponse
-from tcsoa.utils import TcService
+from tcsoa.gen.Internal.Requirementsmanagement._2012_10.RequirementsManagement import MatchLineInputData, MatchedLineResponse, TraceabilityMatrixInfo1
+from tcsoa.base import TcService
 from tcsoa.gen.Internal.Requirementsmanagement._2012_02.RequirementsManagement import TraceabilityMatrixResponse
 
 
