@@ -1,6 +1,6 @@
 from tcsoa.gen.Internal_Vendormanagement._2008_05.services import VendorManagementService as imp0
 from tcsoa.gen.Internal_Vendormanagement._2008_06.services import VendorManagementService as imp1
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class VendorManagementService(TcService):
