@@ -1,8 +1,8 @@
 from __future__ import annotations
 
 from typing import List
-from tcsoa.gen.Internal.Workflowaw._2020_12.Workflow import UpdateTaskAssignmentsInput, TaskAssignmentsInput, TaskAssignmentsResponse, UpdateTaskAssignmentsReponse
-from tcsoa.utils import TcService
+from tcsoa.gen.Internal.Workflowaw._2020_12.Workflow import UpdateTaskAssignmentsReponse, TaskAssignmentsInput, TaskAssignmentsResponse, UpdateTaskAssignmentsInput
+from tcsoa.base import TcService
 
 
 class WorkflowService(TcService):
