@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import ItemRevision, BusinessObject, Folder, WorkspaceObject, Dataset, Item
+from tcsoa.gen.BusinessObjects import BusinessObject, WorkspaceObject, Folder, Dataset, Item, ItemRevision
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
