@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import ItemRevision, Fnd0Markup, Fnd0MarkupChange
+from tcsoa.gen.BusinessObjects import Fnd0MarkupChange, Fnd0Markup, ItemRevision
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
