@@ -1,5 +1,5 @@
 from tcsoa.gen.Translation._2007_06.services import TranslationManagementService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class TranslationManagementService(TcService):
