@@ -1,6 +1,6 @@
 from tcsoa.gen.UiConfig._2014_11.services import UiConfigService as imp0
 from tcsoa.gen.UiConfig._2015_10.services import UiConfigService as imp1
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class UiConfigService(TcService):
