@@ -3,7 +3,7 @@ from __future__ import annotations
 from tcsoa.gen.WProxy._2014_10.ProxyLink import CreateProxyLinkInputInfo
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ProxyLinkService(TcService):
